@@ -145,7 +145,10 @@ class Calc(Parser):
             p[0] = 0
 
     def p_error(self, p):
-        print "Syntax error at '%s'" % p.value
+        if p:
+            print "Syntax error at '%s'" % p.value
+        else:
+            print "Syntax error at EOF"
 
 if __name__ == '__main__':
     calc = Calc()
