@@ -2,7 +2,10 @@
 #
 # Improperly specific ignore declaration
 
-import lex
+import sys
+sys.path.insert(0,"..")
+
+import ply.lex as lex
 
 tokens = [
     "PLUS",
@@ -22,7 +25,6 @@ def t_error(t):
     pass
 
 import sys
-sys.tracebacklimit = 0
 
 lex.lex()
 
