@@ -2,7 +2,10 @@
 #
 # Rule defined as some other type
 
-import lex
+import sys
+sys.path.insert(0,"..")
+
+import ply.lex as lex
 
 tokens = [
     "PLUS",
@@ -17,7 +20,6 @@ t_NUMBER = 1
 def t_error(t):
     pass
 
-import sys
 sys.tracebacklimit = 0
 
 lex.lex()
