@@ -2,7 +2,10 @@
 #
 # Tests for absence of tokens variable
 
-import lex
+import sys
+sys.path.insert(0,"..")
+
+import ply.lex as lex
 
 t_PLUS = r'\+'
 t_MINUS = r'-'
@@ -11,7 +14,6 @@ t_NUMBER = r'\d+'
 def t_error(t):
     pass
 
-import sys
 sys.tracebacklimit = 0
 
 lex.lex()
