@@ -7,6 +7,9 @@
 import sys
 sys.tracebacklimit = 0
 
+sys.path.insert(0,"..")
+import ply.yacc as yacc
+
 # Parsing rules
 precedence = (
     ('left','PLUS','MINUS'),
@@ -58,7 +61,6 @@ def p_expression_name(t):
 def p_error(t):
     print "Syntax error at '%s'" % t.value
 
-import yacc
 yacc.yacc()
 
 
